@@ -216,8 +216,9 @@ class HopprPlugin(ABC):
         """
         Creates a logger with a MemoryHandler, which flushes to stderr when closed
         """
-
-        self._logger = MemoryLogger()
+        self._logger = MemoryLogger(
+            self.context.logfile_location, self.context.logfile_lock
+        )
 
     def get_logger(self) -> MemoryLogger:
         """
