@@ -6,7 +6,7 @@ Transfer business logic
 from __future__ import annotations
 
 from hoppr import utils
-from hoppr.types.transfer_file_content import TransferFileContent
+from hoppr.hoppr_types.transfer_file_content import TransferFileContent
 
 
 class Transfer:
