@@ -40,7 +40,7 @@ class CollectDockerPlugin(CollectorPlugin):
         """
         purl = PackageURL.from_string(comp.purl)
         purl_id = purl.name + ":" + purl.version
-        source_url = os.path.join(repo_url, purl.namespace, purl_id)
+        source_url = os.path.join(repo_url, purl.namespace or "", purl_id)
         source_url = re.sub(r"^https?://", "", source_url)
         if not source_url.startswith("docker://"):
             source_url = "docker://" + source_url
@@ -78,7 +78,7 @@ class CollectDockerPlugin(CollectorPlugin):
                 self.get_logger().info(
                     "Artifact collection failed, deleting file and retrying"
                 )
-                os.remove(target_dir)
+                os.remove(target_path)
             return Result.retry(msg)
 
         return Result.success()
