@@ -38,6 +38,13 @@ def bundle(
         help="Specify transfer config",
         envvar="HOPPR_TRANSFER_CONFIG",
     ),
+    log_file: Path = Option(
+        None,
+        "-l",
+        "--log",
+        help="File to which log will be written",
+        envvar="HOPPR_LOG_FILE",
+    ),
 ):
     """
     Run the stages specified in the transfer config file on the
@@ -56,7 +63,7 @@ def bundle(
     processor = HopprProcessor(transfer, manifest)
     processor.metadata_files = metadata_files
 
-    result = processor.run()
+    result = processor.run(log_file)
     if result.is_fail():
         sys.exit(1)
 
