@@ -3,12 +3,12 @@ Run Hoppr processing, using multiple processors
 """
 from __future__ import annotations
 
-import logging
 import os
 import platform
 import shutil
 import socket
 import tempfile
+import time
 import urllib
 from concurrent.futures import Future, ProcessPoolExecutor
 from datetime import datetime
@@ -19,7 +19,7 @@ from typing import Dict, List, Optional, Tuple
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component  # type: ignore
 from packageurl import PackageURL  # type: ignore
-from typer import echo
+from typer import echo, secho, colors
 
 from hoppr.base_plugins.hoppr import HopprPlugin
 from hoppr.configs.manifest import Manifest
@@ -28,6 +28,7 @@ from hoppr.context import Context
 from hoppr.exceptions import HopprPluginError
 from hoppr.flatten_sboms import flatten_sboms
 from hoppr.hoppr_types.transfer_file_content import Plugin as PluginRef
+from hoppr.mem_logger import MemoryLogger
 from hoppr.net import download_file
 from hoppr.result import Result
 from hoppr.utils import plugin_instance
@@ -73,9 +74,6 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
         Run all processes for this stage
         """
 
-        HopprProcessor.get_logger().info(  # pylint: disable=logging-fstring-interpolation
-            f"---------- Beginning Stage {self.stage_id} ----------"
-        )
         try:
             self.plugins = self._load_plugins()
         except (ModuleNotFoundError, HopprPluginError) as err:
@@ -130,13 +128,18 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
             # Save all the results, count failures and retries
             # Note: future.results() blocks until the process is complete
 
+            need_method_label = True
             failures = 0
             retries = 0
             for future_proc in futures:
                 future_result = future_proc.result()
                 if not future_result.is_skip():
+                    if need_method_label:
+                        echo(f"   Beginning method {method_name}")
+                        need_method_label = False
                     plugin, comp = future_argument_map[future_proc]
                     self._save_result(method_name, plugin, future_result, comp)
+                    self._report_result(plugin, comp, future_result)
 
                     if future_result.is_fail():
                         failures += 1
@@ -153,6 +156,17 @@ class StageProcessor:  # pylint: disable=too-few-public-methods
             f"{failures} '{method_name}' processes failed, and {retries} returned 'retry'"
         )
 
+    @staticmethod
+    def _report_result(plugin, comp, result):
+        desc = f"      {plugin.__class__.__name__} {result.status.name}"
+        if comp is not None:
+            desc = desc + f" for {comp.purl}"
+        color = colors.GREEN
+        if not result.is_success():
+            color = colors.RED
+            desc = desc + f": {result.message}"
+        secho(desc, fg=color)
+
     def _save_result(
         self,
         method_name: str,
@@ -198,55 +212,29 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
     Run the Hoppr process
     """
 
-    @staticmethod
-    def _create_logger() -> logging.Logger:
-        """
-        Creates a logger to stderr
-        """
-
-        logger_name: str = f"HopprProcessor--{os.getpid()}"
-
-        new_logger = logging.getLogger(logger_name)
-        new_logger.setLevel(logging.INFO)
-
-        formatter = logging.Formatter(
-            "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
-        )
-        handler = logging.StreamHandler()
-        handler.setFormatter(formatter)
-
-        new_logger.addHandler(handler)
-        return new_logger
-
-    logger = _create_logger()
-
     def __init__(self, transfer: Transfer, manifest: Manifest) -> None:
         self.transfer = transfer
         self.manifest = manifest
         self.context: Context
         self.stages: Dict = {}
         self.metadata_files: List[Path] = []
+        self.logger: Optional[MemoryLogger] = None
 
-    @classmethod
-    def get_logger(cls):
+    def get_logger(self):
         """
         Returns the logger for this class
         """
-        return cls.logger
+        return self.logger
 
     def _collect_file(self, file_name, target_dir) -> None:
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
-            f"Collecting metadata file {file_name}"
-        )
+        self.get_logger().info(f"Collecting metadata file {file_name}")
         abs_path = os.path.abspath(file_name)
 
         target = os.path.join(target_dir, urllib.parse.quote_plus(abs_path))
         shutil.copyfile(file_name, target)
 
     def _collect_url(self, url, target_dir) -> None:
-        self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
-            f"Collecting metadata from url {url}"
-        )
+        self.get_logger().info(f"Collecting metadata from url {url}")
         target = os.path.join(target_dir, urllib.parse.quote_plus(url))
         download_file(url, target, None)
 
@@ -268,6 +256,7 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
                 self._collect_url(bom_ref.url, target_dir)
 
     def _collect_metadata(self):
+        echo("Collecting Hoppr Metadata")
         target_dir = f"{self.context.collect_root_dir}/generic/_metadata_/"
         os.makedirs(target_dir, exist_ok=True)
 
@@ -335,7 +324,7 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
         )
         return total_failure_count
 
-    def run(self) -> Result:
+    def run(self, log_file: Optional[Path] = None) -> Result:
         """
         Run the Hoppr process executing each stage in turn
         """
@@ -352,22 +341,49 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
             if self.transfer.content:
                 self.context.max_processes = self.transfer.content.max_processes
 
-            self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
+            logger_name: str = f"HopprProcessor--{os.getpid()}"
+
+            self.context.logfile_location = (
+                f"hoppr_{time.strftime('%Y%m%d-%H%M%S')}.log"
+            )
+            if log_file is not None:
+                self.context.logfile_location = str(log_file)
+
+            self.logger = MemoryLogger(
+                self.context.logfile_location,
+                lock=self.context.logfile_lock,
+                log_name=logger_name,
+                flush_immed=True,
+            )
+
+            self.get_logger().info(
+                f"Beginning Hoppr Process execution, max_processes={self.context.max_processes}"
+            )
+            echo(
                 f"Beginning Hoppr Process execution, max_processes={self.context.max_processes}"
             )
             self._collect_metadata()
 
             if self.transfer.content is not None:
                 for stage_ref in self.transfer.content.stages:
+                    self.get_logger().info(
+                        f"---------- Beginning Stage {stage_ref.name} ----------"
+                    )
+                    echo(f"---------- Beginning Stage {stage_ref.name} ----------")
+
                     stage = StageProcessor(
                         stage_ref.name, self.context, stage_ref.plugins
                     )
                     self.stages[stage_ref.name] = stage
                     result = stage.run()
                     if result.is_fail() or result.is_retry():
-                        self.logger.error(  # pylint: disable=logging-fstring-interpolation
+                        self.logger.error(
                             f"Stage {stage_ref.name} failed, processing terminated: {result.message}"
                         )
+                        secho(
+                            f"   Stage {stage_ref.name} failed, processing terminated: {result.message}",
+                            fg=colors.RED,
+                        )
                         break
 
                     self._collect_bom()
